@@ -2,12 +2,16 @@ use 5.012;
 use MooseX::Declare;
 use Method::Signatures::Modifiers;
 
+# PODNAME: Dist::Zilla::PluginBundle::BAREFOOT
+# PODNAME: Dist::Zilla::PluginBundle::BAREFOOT
 class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::Easy
 {
-	use autodie										2.00				;
-	use List::MoreUtils											'uniq'	;
-	use MooseX::Has::Sugar												;
-	use MooseX::Types::Moose									':all'	;
+	use autodie										2.00					;
+	use PerlX::Maybe								0.003		'provided'	;
+	use List::MoreUtils											'uniq'		;
+	use MooseX::Has::Sugar													;
+	use MooseX::Types::Moose									':all'		;
+	use MooseX::ClassAttribute												;
 
 	# Dependencies
 	use Dist::Zilla									4.3			  ;		# authordeps
@@ -30,15 +34,20 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 	use Dist::Zilla::Plugin::CopyFilesFromBuild					();
 	use Dist::Zilla::Plugin::CheckPrereqsIndexed	0.002		();
 	use Dist::Zilla::Plugin::CheckVersionIncrement	0.121750	();
-	#use Dist::Zilla::Plugin::MetaProvides::Package	1.14		();		# hides DB/main/private packages
+	use Dist::Zilla::Plugin::MetaProvides::Package	1.14		();		# hides DB/main/private packages
+	use Dist::Zilla::Plugin::MetaProvides::Class	2.001		();		# adds 'provides' to META.* for `class`
+	use Dist::Zilla::Plugin::PodnameFromClassname	0.1100		();		# stops Pod::Weaver from complaining
 	use Dist::Zilla::Plugin::CheckChangesHasContent				();
 
 
-	our $VERSION = '0.03_05'; # VERSION
+	our $VERSION = '0.06_02'; # TRIAL VERSION
 
 	my @dirty_files = qw< dist.ini Changes >;
 	my @exclude_generated_files = qw< README.pod META.json >;
 
+	class_has weaver_payload	=>	( ro, writer => '_store_weaver_data', isa => HashRef, lazy,
+											default => sub { die "class attribute weaver_payload called too soon!" }, );
+
 
 	sub mvp_multivalue_args { qw/stopwords/ }
 
@@ -48,7 +57,6 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 	has auto_prereq		=>	( ro, isa => Bool, lazy, default => method { $self->payload->{'auto_prereq'} // 1 } );
 	has tag_format		=>	( ro, isa => Str, lazy, default => method { $self->payload->{'tag_format'} // 'v%v' } );
 	has version_regexp	=>	( ro, isa => Str, lazy, default => method { $self->payload->{'version_regexp'} // '^v(.+)$' } );
-	has weaver_config	=>	( ro, isa => Str, lazy, default => method { $self->payload->{'weaver_config'} // '@BAREFOOT' } );
 	has git_remote		=>	( ro, isa => Str, lazy, default => method { $self->payload->{'git_remote'} // 'origin' } );
 	has legal_addendum	=>	( ro, isa => Str, lazy, default => method { $self->payload->{'legal_addendum'} // '' } );
 
@@ -67,15 +75,14 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 			#PruneCruft					=>														# core
 			#ManifestSkip				=>														# core
 
-		( $self->auto_prereq
-		?	[ AutoPrereqs				=>	{ skip => "^t::lib" } ]
-		:	()
-		),
+provided $self->auto_prereq,
+			[ AutoPrereqs				=>	{ skip => "^t::lib" } ],
 			#
 			# file munging
 			OurPkgVersion				=>
+			PodnameFromClassname		=>
 			#InsertCopyright				=>
-			[ PodWeaver					=>	{ config_plugin => $self->weaver_config } ],
+			[ PodWeaver					=>	{ config_plugin => '@BAREFOOT', } ],
 
 			# generated distribution files
 			License						=>														# core
@@ -85,16 +92,14 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 												location	=> 'root',
 											}
 			],
-			[ Bugtracker				=>	{ web => 'http://github.com/me/%l/issues' } ],
+			[ Bugtracker				=>	{ web => 'http://github.com/barefootcoder/%l/issues' } ],
 
 #			# generated xt/ tests
-#		( $self->no_spellcheck
-#		?	()
-#		:	[ 'Test::PodSpelling'		=>	{ stopwords => $self->stopwords } ]
-#		),
+#provided not $self->no_spellcheck,
+#			[ 'Test::PodSpelling'		=>	{ stopwords => $self->stopwords } ],
 #			MetaTests					=>														# core
-#			PodSyntaxTests				=>														# core
-#			PodCoverageTests			=>														# core
+			PodSyntaxTests				=>														# core
+			PodCoverageTests			=>														# core
 #			'Test::Version'				=>
 
 			# metadata
@@ -105,7 +110,7 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 			#									package		=> [qw< DB >]
 			#								}
 			#],
-			#[ 'MetaProvides::Package'	=>	{ meta_noindex => 1 } ],							# AFTER MetaNoIndex
+			[ 'MetaProvides::Class'		=>	{ inherit_version => 1 } ],							# AFTER MetaNoIndex
 			#MetaYAML					=>														# core
 			MetaJSON					=>														# core
 
@@ -125,15 +130,14 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 			CheckVersionIncrement		=>
 			#CheckPrereqsIndexed			=>
 			CheckChangesHasContent		=>
-			#CheckExtraTests				=>
+			CheckExtraTests				=>
 			TestRelease					=>														# core
 			ConfirmRelease				=>														# core
 
 			# release
-		( $self->fake_release
+$self->fake_release
 		?	'FakeRelease'
-		:	'UploadToCPAN'																		# core
-		),
+		:	'UploadToCPAN',																		# core
 
 			# after release
 			# Note -- NextRelease is here to get the ordering right with
@@ -158,6 +162,9 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 
 		);
 
+		my @weaver_params = qw< repository_link >;
+		$self->_store_weaver_data({ map { $_ => $self->payload->{$_} } @weaver_params });
+
 	}
 
 }
@@ -177,7 +184,7 @@ Dist::Zilla::PluginBundle::BAREFOOT - Dist::Zilla configuration the way BAREFOOT
 
 =head1 VERSION
 
-This document describes version 0.03_05 of Dist::Zilla::PluginBundle::BAREFOOT.
+This document describes version 0.06_02 of Dist::Zilla::PluginBundle::BAREFOOT.
 
 =head1 SYNOPSIS
 
@@ -218,7 +225,7 @@ This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the followin
  
  	; should this be in metadata section?
  	[Bugtracker]
- 	web = http://github.com/me/%l/issues
+ 	web = http://github.com/barefootcoder/%l/issues
  
  	; xt tests
  	;[Test::PodSpelling]					; xt/author/pod-spell.t
@@ -245,6 +252,8 @@ This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the followin
  	; can't get this one to work right ATM
  	; [MetaProvides::Package]			; add 'provides' to META files
  	; meta_noindex = 1					; respect prior no_index directives
+ 	[MetaProvides::Class]				; add 'provides' to META files for classes
+ 	inherit_version = 1 				; use version from dist.ini
  
  	; build system
  	[ExecDir]							; include 'bin/*' as executables
@@ -264,7 +273,7 @@ This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the followin
  	;[CheckPrereqsIndexed]				; ensure prereqs are on CPAN
  	[CheckVersionIncrement]				; ensure version has been bumped
  	[CheckChangesHasContent]			; ensure Changes has been updated
- 	;[CheckExtraTests]					; ensure xt/ tests pass
+ 	[CheckExtraTests]					; ensure xt/ tests pass
  	[TestRelease]						; ensure t/ tests pass
  	[ConfirmRelease]					; prompt before uploading
  
@@ -327,16 +336,16 @@ risking a real release.
 
 =item *
 
-C<<< weaver_config >>> -- Specifies a Pod::Weaver bundle.  Defaults to @BAREFOOT.
-
-=item *
-
 C<<< stopwords >>> -- Add stopword for Test::PodSpelling (can be repeated).
 
 =item *
 
 C<<< no_spellcheck >>> -- Omit Test::PodSpelling tests.
 
+=item *
+
+C<<< repository_link >>> -- Override the Pod::Weaver L<Support> section default (which is "both").
+
 =back
 
 =head1 INSTALLATION
@@ -372,12 +381,12 @@ You can find documentation for this module with the perldoc command.
 
 =head2 Bugs / Feature Requests
 
-		This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
-		via TDD (Test-Driven Development), so a patch that includes a failing test is much more
-		likely to get accepted (or least likely to get accepted more quickly).
+This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
+via TDD (Test-Driven Development), so a patch that includes a failing test is much more
+likely to get accepted (or at least likely to get accepted more quickly).
 
-		If you just want to report a problem or suggest a feature, that's okay too.  You can create
-		an issue on GitHub here: L<http://github.com/me/dist-zilla-pluginbundle-barefoot/issues>.
+If you just want to report a problem or suggest a feature, that's okay too.  You can create
+an issue on GitHub here: L<http://github.com/barefootcoder/dist-zilla-pluginbundle-barefoot/issues>.
 
 =head2 Source Code
 
@@ -392,7 +401,7 @@ Buddy Burden <barefoot@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Buddy Burden.
+This software is Copyright (c) 2020 by Buddy Burden.
 
 This is free software, licensed under:
 
