@@ -1,8 +1,14 @@
-use strict;
-use warnings;
+use 5.012;
+use MooseX::Declare;
+use Method::Signatures::Modifiers;
 
+# PODNAME: Pod::Weaver::PluginBundle::BAREFOOT
+# PODNAME: Pod::Weaver::PluginBundle::BAREFOOT
+class Pod::Weaver::PluginBundle::BAREFOOT
 {
-	package Pod::Weaver::PluginBundle::BAREFOOT;
+	use autodie										2.00				;
+	use MooseX::Has::Sugar												;
+	use MooseX::Types::Moose									':all'	;
 
 	# Dependencies
 	use Pod::Weaver 3.101635; # fixed ABSTRACT scanning
@@ -13,22 +19,29 @@ use warnings;
 	use Pod::Weaver::Section::Support 1.001 ();
 
 
-	our $VERSION = '0.03_05'; # VERSION
+	our $VERSION = '0.06_02'; # TRIAL VERSION
 
-	my $bugtracker_content = <<'END';
+
+	my $bugtracker_content = <<'END' =~ s/^\h+//mgr;
 		This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
 		via TDD (Test-Driven Development), so a patch that includes a failing test is much more
-		likely to get accepted (or least likely to get accepted more quickly).
+		likely to get accepted (or at least likely to get accepted more quickly).
 
 		If you just want to report a problem or suggest a feature, that's okay too.  You can create
 		an issue on GitHub here: {WEB}.
 END
 
 
-	sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
+	method _exp { Pod::Weaver::Config::Assembler->expand_package($self) }
 
-	sub mvp_bundle_config
+	method mvp_bundle_config ($class: ...)
 	{
+		# get payload (configurable parameters) from the dzil plugin bundle
+		my $payload = Dist::Zilla::PluginBundle::BAREFOOT->weaver_payload;
+
+		# now set default values for them
+		$payload->{'repository_link'}	//= 'both';
+
 		my @plugins;
 		push @plugins, (
 			[ '@BAREFOOT/WikiDoc',     _exp('-WikiDoc'),	{} ],
@@ -61,7 +74,7 @@ END
 																websites			=> 'none',
 																bugs				=> 'metadata',
 																bugs_content		=> $bugtracker_content,
-																repository_link		=> 'both',
+																repository_link		=> $payload->{'repository_link'},
 																repository_content	=> 'none',
 															}
 			],
@@ -90,7 +103,7 @@ Pod::Weaver::PluginBundle::BAREFOOT - BAREFOOT's default Pod::Weaver config
 
 =head1 VERSION
 
-This document describes version 0.03_05 of Pod::Weaver::PluginBundle::BAREFOOT.
+This document describes version 0.06_02 of Pod::Weaver::PluginBundle::BAREFOOT.
 
 =head1 DESCRIPTION
 
@@ -167,7 +180,7 @@ Buddy Burden <barefoot@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Buddy Burden.
+This software is Copyright (c) 2020 by Buddy Burden.
 
 This is free software, licensed under:
 
